#
# spec file for package python-hp3parclient
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} %{!?skip_python3:python3-%{**}}}
Name:           python-hp3parclient
Version:        3.3.2
Release:        bp154.1.24
Summary:        HP 3PAR HTTP REST Client
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            http://pypi.python.org/pypi/hp3parclient
Source:         https://files.pythonhosted.org/packages/source/h/hp3parclient/hp3parclient-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module eventlet}
BuildRequires:  %{python_module paramiko}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
#BuildRequires:  %{python_module nose}
Requires:       python-eventlet
Requires:       python-paramiko
Requires:       python-requests
BuildArch:      noarch
%python_subpackages

%description
This is a Client library that can talk to the HP 3PAR Storage array.  The 3PAR
storage array has a REST web service interface and a command line interface.
This client library implements a simple interface for talking with either
interface, as needed.  The python httplib2 library is used to communicate
with the REST interface.  The python paramiko library is used to communicate
with the command line interface over an SSH connection.

This branch requires 3.1.3 version MU1 of the 3PAR firmware.
File Persona capabilities require 3PAR firmware 3.2.1 Build 46 or later.

%prep
%setup -q -n hp3parclient-%{version}

%build
%python_build

%install
%python_install
# remove the tests from distribution
%python_expand rm -rf %{buildroot}%{$python_sitelib}/test/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

#NOTE(saschpe): Needs HP 3PAR storage?
#%%check
#nosetests

%files %{python_files}
%doc README.rst
%{python_sitelib}/*

%changelog
* Mon Apr 23 2018 tchvatal@suse.com
- Convert to singlespec
- Remove test folder shipped in sitelib
* Wed Feb 14 2018 tbechtold@suse.com
- update to 3.3.2:
  * Use a simpler random hostname for findHost
  * Fix issue #5: SSH session never renewed if lost
  * Safely access hostname in VLUN
  * Adding unit tests for the Exception class
  * Update copyVolume to remove destCPG offline copy
  * Improve list handling in File Persona get commands
  * Less nargs/more shlex to fix fake SSH usage error
  * Replaces httplib2 with Python Requests support
  * Fix createVLUN with LUN ID 0 issue
  * Adding more descriptive debug messages to client __init__
  * Adds API to retrieve a volumes snapshots
  * Unity test fix to allow bondMode 6
  * Fixing client initialization error when ex_desc is None
  * Allow suppressing of SSL log warnings
  * Changes exception's isinstance str to basestring
  * Fix file client for 3.2.1 MU3.
  * Fix logging to allow diagnosis of multi-line-stripper errors
  * Adding support for VLUN queries in getVLUN and getHostVLUNs
  * Add retries for certain exceptions
  * Fix intermitent failures get_all_volume_metadata
  * Making the client Python3.4+ Compliant
  * Adding support for calling srstatld with a given interval and history
  * Fix JSON parsing using Python3
  * Fix inconsistent Unity unit tests
  * Enable Unity unit tests with the paramiko test server
  * Fixes documenation errors for 3.2.2 release
  * Removing 'active' VLUN check from getVLUN call
  * Adding Volume Set Snapshot Capabilities to Client
  * Update findHost to use a random hostname
  * Adding support for calling srstatld
  * Add -ca option for create/set fshare (SMB)
  * Added exceptions to API docs for deleteVolume
  * Fixed bug in setSSHOptions File Persona example.
  * Skip flash cache tests on backends without it
- Fix Source url
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 3.2.0:
  * Added File Persona Client: getfs, createfpg, growfpg, getfpg,
    setfpg, removefpg, createvfs, getvfs, setvfs, removevfs,
    createfsip, setfsip, getfsip, removefsip, createfsgroup,
    setfsgroup, removefsgroup, createfsuser, setfsuser,
    removefsuser, createfstore, getfstore, setfstore, removefstore,
    createfshare, setfshare, getfshare, removefshare, createfsnap,
    getfsnap, removefsnap, startfsnapclean, getfsnapclean,
    stopfsnapclean, setfsquota, getfsquota, gettpdinterface
  * Added paramiko SSH simulator initially supporting just a few
    test cases.
  * Fixed PEP8 violations.
  * Change GitHub account reference from WaltHP to hp-storage.
  * Modify the steps in the Installing from Source section to
    ensure correct installation of dependencies and ordering.
  * Added support for flash cache policy set on a virtual volume
    set.
  * Added tox environments to run tests with code coverage and to
    generate the documentation
  * Consolidated the test/README.rst into the top level README.rst
    and added clarifications
- additional changes from version 3.1.3:
  * Added ‘paramiko’ and ‘eventlet’ requirements to setup.py.
    Running a standard python setup.py install should install these
    modules now if they are missing.
  * Use static loggers to fix duplicate logging problem.
  * Update unit tests to better support more backend configurations
    and versions.
  * Made corrections to the API documentation.
- additional changes from version 3.1.2:
  * Added API: findAllVolumeSets, getCPGAvailableSpace,
    getOverallSystemCapacity
  * Revised unit tests to use asserts instead of try/catch/except
    blocks.
  * Removed SSH call from the findVolumeSet method and replaced it
    with REST.
  * Improved findVolumeSet documentation.
  * Changed SSH connections to now only get created when an SSH
    command needs to be executed.
  * Added closing of an SSH connection during logout if one is
    active.
  * Changed SSH connections to no longer use keep-alive packets to
    stay active.
  * Removed an unneeded print statement output that was occuring
    when an SSH connection was closed.
- additional changes from version 3.1.1:
  * Added known_host_file and missing_key_policy parameters to: -
    HP3ParClient.setSSHOptions - HP3PARSSHClient
  * Fixed an issue with building the ClientException when body of
    the response was empty.
  * Fixed spelling error in urllib import for Python 3.0 or greater
    environments.
- additional changes from version 3.1.0:
  * Added APIs: setVolumeMetaData, getVolumeMetaData,
    getAllVolumeMetaData, removeVolumeMetaData, findVolumeMetaData
  * Added two new enumerations for CHAP initiator and target.
  * Converted existing metadata functions to use REST API calls
    instead of SSH.
  * Updated the minimum required HP 3PAR build version to be
    3.1.3.230. This corresponds to 3.1.3 MU1 firmware.
  * Added support for volume metadata REST API calls in the flask
    server.
  * Numerous API documentation improvements
  * Fixed 2 enumerations: PORT_TYPE_RCIP changed to 7,
    PORT_TYPE_ISCSI changed to 8
  * Numerous Enumerations added: Port Type, Port Protocol, Task
    Type, VLUN Type, CPG RAID, CPG HA, CPG Chunklet, CPG Disk Type,
    Host Persona
  * Added host set API: findHostSet, getHostSets, getHostSet,
    createHostSet, deleteHostSet, modifyHostSet, addHostToHostSet,
    removeHostFromHostSet, removeHostFromItsHostSet
  * Added showpatch API: getPatch, getPatches
  * Fixed missing tearDown() to improve flask server shutdown.
  * Added VLUN and host set check before allowing deleteHost.
  * Fixed some flask error codes and error messages to match array.
  * Removed the ‘test_’ prefix from classes that don’t contain
    tests.
  * Reduced volume sizes used in tests.
  * Made domain and cpg_ldlayout_ha configurable.
  * Added more tests.
  * Fixed an incorrect exception message for getHostVLUNs.
- add python-eventlet and python-paramiko as BuildRequires
  to guarantee their availability
- update description: now requires 3.1.3 version MU1 of the 3PAR
  firmware
* Thu Feb 13 2014 dmueller@suse.com
- update to 3.0.0:
  * Requires the 3.1.3 3PAR Firmware or greater.
  * Added new 3.1.3 firmware APIs.
  * Added support for QOS and Virtual Volume sets
  * Added query host by wwns or iqns
  * Added APIs for getTasks, stopOfflinePhysicalCopy, modifyVolume
  * Changes in Version 2.9.2
  * Removed the ssh pooling to fix an issue with timeouts
  * Changes in Version 2.9.1
  * Renamed stopPhysicalCopy to stopOnlinePhysicalCopy
  * Changes in Version 2.9.0
  * Added SSH interface
  * Added stopPhysicalCopy
  * updated doc string to fix some pylint
* Wed Sep  4 2013 speilicke@suse.com
- Update to version 2.0.0:
  + Upstream provides no changelog
- Changes from Version 1.1.0:
  + Added support for hosts and ports
- Changes from Version 1.0.1:
  + The unit tests now work when running nosetest from the top level dir
    and from the test dir
* Mon Jan 14 2013 saschpe@suse.de
- Initial version
